## Gaussian Quadrature

::: beignet.gauss_laguerre_quadrature
::: beignet.gauss_legendre_quadrature
::: beignet.gauss_physicists_hermite_polynomial_quadrature
::: beignet.gauss_probabilists_hermite_polynomial_quadrature
